coala-json
==========

|Linux Build Status| |Windows Build status| |Documentation Status| |MIT|

=====

coala-json holds a collection of useful utilities that are used
to read JSON output from coala and convert it to other test formats.
Currently coala-json supports formats like TAP, JUnit and Checkstyle.
You can easily extend coala-json to your project by simply providing
a custom json-loader file. For more information you can visit our
`documentation <https://coala-json.readthedocs.io/en/latest/>`_.


.. |Linux Build Status| image:: https://gitlab.com/coala/coala-json/badges/master/pipeline.svg
   :target: https://gitlab.com/coala/coala-json/commits/master
.. |Windows Build status| image:: https://img.shields.io/appveyor/ci/coala/coala-json/master.svg?label=windows%20build
   :target: https://ci.appveyor.com/project/coala/coala-json/branch/master
.. |Documentation Status| image:: https://readthedocs.org/projects/coala-json/badge/?version=latest
   :target: https://coala-json.readthedocs.io/en/latest/
.. |MIT| image:: https://img.shields.io/pypi/l/coala-json.svg
   :target: https://opensource.org/licenses/MIT


`Install coala-json <https://pypi.org/project/coala-json/>`_ | `Get Involved <http://coala.io/#/getinvolved>`_
